/**
 * test-webid
 * Copyright (C) 2011 Thomas Bergwinkl
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.bergnet.test;

import java.lang.reflect.Method;

import com.hp.hpl.jena.rdf.model.Model;
import com.hp.hpl.jena.rdf.model.ModelFactory;
import com.hp.hpl.jena.rdf.model.Resource;
import com.hp.hpl.jena.vocabulary.DCTerms;
import com.hp.hpl.jena.vocabulary.RDF;


@SuppressWarnings("rawtypes")
public class EarlTestCriterionRDFBuilder {
	public static Model build(Class[] testClasses) {
		Model model = ModelFactory.createDefaultModel();

		for(Class testClass : testClasses) {
			for(Method method : testClass.getMethods()) {
				if(method.isAnnotationPresent(EarlTestCase.class))
					addTestCase(model, method.getAnnotation(EarlTestCase.class));
			}
		}

		return model;
	}

	private static void addTestCase(Model model, EarlTestCase earlTestCase) {
		Resource test = model.createResource(earlTestCase.url())
				.addProperty(RDF.type, model.createResource("http://www.w3.org/ns/earl#TestCase"));

		if(earlTestCase.title() != null && !earlTestCase.title().isEmpty())
			test.addProperty(DCTerms.title, earlTestCase.title());

		if(earlTestCase.description() != null && !earlTestCase.description().isEmpty())
			test.addProperty(DCTerms.description, earlTestCase.description());
	}
}
