package org.bergnet.test.webid.publishers;

import java.io.IOException;
import java.net.InetSocketAddress;
import java.net.URL;
import java.util.HashMap;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.bergnet.test.webid.WebIDTestException;
import org.bergnet.test.webid.WebIDTests;
import org.eclipse.jetty.server.Request;
import org.eclipse.jetty.server.Server;
import org.eclipse.jetty.server.handler.AbstractHandler;


public class JettyFOAFPublisher implements FOAFPublisher {
	Server server = null;
	EmbeddedServer embeddedServer = null;
	URL baseUrl = null;

	public JettyFOAFPublisher(WebIDTests.Config configuration) throws WebIDTestException {
		try {
			baseUrl = configuration.getBaseUrl();
			InetSocketAddress socketAddress = new InetSocketAddress(baseUrl.getHost(), baseUrl.getPort());
			server = new Server(socketAddress);
			embeddedServer = new EmbeddedServer();
			server.setHandler(embeddedServer);
			server.start();
		} catch(Exception e) {
			throw new WebIDTestException("Can't start Jetty WebServer");
		}

		/*try {
			InetAddress inetAddress = InetAddress.getLocalHost();
			String hostName = inetAddress.getHostName();
			//baseUrl = "http://" + hostname + ":8080/";
		} catch (Exception e) {
			throw new WebIDTestException("Can't resolv own hostname");
		}*/
	}

	public void stop() throws WebIDTestException {
		try {
			server.stop();
		} catch(Exception e) {}
	}

	public URL getBaseUrl() {
		return baseUrl;
	}

	public void publish(String id, String foaf, String contentType) throws WebIDTestException {
		embeddedServer.setContent(baseUrl + id, foaf, contentType);
	}

	private static class EmbeddedServer extends AbstractHandler {
		HashMap<String, String> contentMap = new HashMap<String, String>();
		HashMap<String, String> contentTypeMap = new HashMap<String, String>();

		public void handle(String target, Request baseRequest, HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
			String url = getRequestUrl(request);
			String content = contentMap.get(url);
			String contentType = contentTypeMap.get(url);

			if(content != null) {
				response.setStatus(200);
				response.setContentType(contentType);
				response.getWriter().write(content);
			} else {
				response.setStatus(404);
			}

			baseRequest.setHandled(true);
		}

		public void setContent(String uri, String content, String contentType) {
			contentMap.put(uri, content);
			contentTypeMap.put(uri, contentType);
		}

		private String getRequestUrl(HttpServletRequest request) {
			String scheme = request.getScheme();
			String serverName = request.getServerName();
			String serverPort = (scheme == "http" && request.getServerPort() == 80 ? "" : (scheme == "https" && request.getServerPort() == 443 ? "" : ":" + request.getServerPort()));
			String path = request.getRequestURI();

			return scheme + "://" + serverName + serverPort + path;
		}
	}
}
 