/**
 * test-webid
 * Copyright (C) 2011 Thomas Bergwinkl
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.bergnet.test.webid.testcases;

import org.bergnet.test.EarlTestCase;
import org.bergnet.test.webid.WebIDTestException;
import org.bergnet.test.webid.WebIDTests;
import org.bergnet.webid.commons.FOAFBuilder;
import org.junit.Assert;
import org.junit.Test;


public class SimpleTurtle extends AbstractTestCase {
	public SimpleTurtle() throws Exception {
		id = "simple.ttl";
		verificationQuery = "PREFIX earl: <http://www.w3.org/ns/earl#>\n" +
				"PREFIX wit: <http://www.w3.org/2005/Incubator/webid/earl/RelyingParty#>\n" +
				"ASK WHERE {\n" +
				"	?webidAuthenticationAssertion\n" +
				"		earl:test wit:webidAuthentication;\n" +
				"		earl:result ?webidAuthenticationResult.\n" +
				"	?webidAuthenticationResult\n" +
				"		earl:outcome earl:passed;\n" +
				"		earl:pointer ?webidClaim.\n" +
				"	?webidClaim wit:claimedIdentity ?webidString }";

		init();
	}

	public String buildFOAF() throws WebIDTestException {
		try {
			foaf = FOAFBuilder.build(this.webid, FOAFBuilder.FORMAT_TURTLE);

			dump("foaf.ttl", foaf);

			return foaf;
		} catch(Exception e) {
			throw new WebIDTestException("Can't build FOAF file", e);
		}
	}

	public void publishFOAF() throws WebIDTestException {
		WebIDTests.getInstance().getPublisher().publish(id, foaf, FOAFBuilder.FORMAT_TURTLE);
	}

	@EarlTestCase(
			url="http://www.w3.org/2005/Incubator/webid/earl/TestSuite#simpleTurtle",
			title="Simple authentication with turtle FOAF file works?",
			description="Simple test using Turtle FOAF and single URI")
	@Test
	public void test() throws Exception {
		generateWebID();
		buildFOAF();
		publishFOAF();
		login();
		verifyOutput();

		Assert.assertTrue(result);
	}
}
